.. warning::
    The Inmanta dashboard has been deprecated in favour of the `Inmanta Web Console <extensions/inmanta-ui/index.html>`_.

Dashboard documentation
=======================

.. toctree::
    :maxdepth: 2
    :glob:

    dashboard/*

